@@ -5,7 +5,7 @@ from convisoappsec.flow.version_searchers import TimeBasedVersionSearcher
 from convisoappsec.flow.version_control_system_adapter import GitAdapter
 from convisoappsec.flowcli.context import pass_flow_context
 from convisoappsec.flowcli import help_option
-from convisoappsec.flowcli.common import project_code_option
+from convisoappsec.flowcli.common import project_code_option, on_http_error
 from convisoappsec.flowcli.deploy.create.context import pass_create_context
 from convisoappsec.flowcli.deploy.create.with_.tag_tracker.context import (
     pass_tag_tracker_context
@@ -85,4 +85,5 @@ def time_(
             create_context.output_formatter.format(deploy)
         )
     except Exception as e:
+        on_http_error(e)
         raise click.ClickException(str(e)) from e
