@@ -6,7 +6,7 @@ from convisoappsec.flowcli import help_option
 from convisoappsec.flowcli.deploy.create.context import pass_create_context
 from convisoappsec.flow import GitAdapter
 from convisoappsec.flow import api
-from convisoappsec.flowcli.common import project_code_option
+from convisoappsec.flowcli.common import project_code_option, on_http_error
 
 
 @click.command()
@@ -108,4 +108,5 @@ def values(
             create_context.output_formatter.format(deploy)
         )
     except Exception as e:
+        on_http_error(e)
         raise click.ClickException(str(e)) from e
